@@ -20,8 +20,8 @@ from typing import (
     Any,
     Callable,
     Dict,
+    List,
     Optional,
-    Tuple,
     Type,
     TypeVar,
     Union,
@@ -65,6 +65,11 @@ class json_options:
     # Uses the name of this field by default.
     name: Optional[str] = None
 
+    # A list of possible names for this field when converting to dataclass.
+    # It will match in order, the first matched name will be used.
+    # The first name in the list will be used when converting to json.
+    name_choice: Optional[List[str]] = None
+
     # A function that returns a custom key to be mapping in the dictionary
     #   whenever converting to dictionary or dataclass.
     # This option is similar to option `name`, but it's a function rather than a string.
@@ -324,6 +329,7 @@ class JSONAble:
 
         d: JSON = {}
 
+        __name_choice_map = getattr(self, "__name_choice_map", None)
         for name, f in self.__dataclass_fields__.items():
             t = self._get_typing_hint_by_field(f)
             v = getattr(self, name)  # Field's value
@@ -338,7 +344,12 @@ class JSONAble:
                     continue
 
             # Key in dictionary `d`.
-            k = _util_get_field_key(name, options, Action.ENCODING)
+            k = _util_get_field_keys(
+                name=name,
+                options=options,
+                action=Action.ENCODING,
+                choice_map=__name_choice_map,
+            )[0]
 
             # Encode.
             encoder = options.encoder or self.get_encoder(t)
@@ -356,20 +367,29 @@ class JSONAble:
         # Arguments for class `cls()`.
         kwds = {}
 
+        _name_choice_map = {}
+
         for name, f in cls.__dataclass_fields__.items():
             t = cls._get_typing_hint_by_field(f)
 
             options = cls._get_json_options(f)
 
             # Key in dictionary.
-            k = _util_get_field_key(name, options, Action.DECODING)
+            ks = _util_get_field_keys(name, options, Action.DECODING)
 
             if options.skip:
                 continue
 
-            v = None
+            # Find the first key in dictionary `d` that is in `ks`.
+            k = None
+            for _k in ks:
+                if _k in d:
+                    k = _k
+                    # record the key in dictionary `d` for this field.
+                    _name_choice_map[name] = k
+                    break
 
-            if k not in d:
+            if k is None:
                 # Key is missing in dictionary.
                 default_on_missing = options.default_on_missing
                 if default_on_missing is not None:
@@ -380,9 +400,8 @@ class JSONAble:
                     # An error like "missing 1 required positional argument" will be raised if this field doesn't
                     # have a default value declared.
                     continue
-
-            # Value in dictionary `d`.
-            if v is None:
+            else:
+                # Value in dictionary `d`.
                 v = d[k]
 
             if options.omitempty:
@@ -401,6 +420,7 @@ class JSONAble:
 
         inst = cls(**kwds)
         setattr(inst, "__dataclass_origin_json__", d)
+        setattr(inst, "__name_choice_map", _name_choice_map)
         return inst  # type: ignore
 
 
@@ -469,18 +489,32 @@ def _replace_mapping_proxy(m: MappingProxyType, kwds) -> MappingProxyType:
     return MappingProxyType(d)
 
 
-def _util_get_field_key(name: str, options: json_options, action: Action) -> str:
+def _util_get_field_keys(
+    name: str,
+    options: json_options,
+    action: Action,
+    choice_map: Optional[JSON] = None,
+) -> List[str]:
     """A util function returns the `key` in target dictionary.
     :param name: the field's name.
     :param options: the json_options for this field.
     """
     if options.name:
-        return options.name
+        return [options.name]
+
+    if action == Action.DECODING and options.name_choice:
+        # get the candidates for this field.
+        return options.name_choice + [name]
+
+    if action == Action.ENCODING and choice_map and name in choice_map:
+        # if the name is chosen from `name_choice`, use the chosen name.
+        # else use the original name.
+        return [choice_map[name]]
 
     if action == Action.DECODING and options.name_inverter:
-        return options.name_inverter(name)
+        return [options.name_inverter(name)]
 
     if options.name_converter:
-        return options.name_converter(name)
+        return [options.name_converter(name)]
 
-    return name
+    return [name]
